@@ -332,7 +332,8 @@ drizzle_column_st *drizzle_column_create(drizzle_result_st *result,
     column= malloc(sizeof(drizzle_column_st));
     if (column == NULL)
     {
-      DRIZZLE_ERROR_SET(result->con->drizzle, "drizzle_column_create", "malloc")
+      drizzle_set_error(result->con->drizzle, "drizzle_column_create",
+                        "malloc");
       return NULL;
     }
 
@@ -454,12 +455,12 @@ const uint8_t *drizzle_column_default_value(drizzle_column_st *column,
 
 drizzle_return_t drizzle_column_skip(drizzle_result_st *result)
 {
-  if (DRIZZLE_STATE_NONE(result->con))
+  if (drizzle_state_none(result->con))
   {
     result->options|= DRIZZLE_RESULT_SKIP_COLUMN;
 
-    DRIZZLE_STATE_PUSH(result->con, drizzle_state_column_read)
-    DRIZZLE_STATE_PUSH(result->con, drizzle_state_packet_read)
+    drizzle_state_push(result->con, drizzle_state_column_read);
+    drizzle_state_push(result->con, drizzle_state_packet_read);
   }
 
   return drizzle_state_loop(result->con);
@@ -469,12 +470,12 @@ drizzle_column_st *drizzle_column_read(drizzle_result_st *result,
                                        drizzle_column_st *column,
                                        drizzle_return_t *ret_ptr)
 {
-  if (DRIZZLE_STATE_NONE(result->con))
+  if (drizzle_state_none(result->con))
   {
     result->column= column;
 
-    DRIZZLE_STATE_PUSH(result->con, drizzle_state_column_read)
-    DRIZZLE_STATE_PUSH(result->con, drizzle_state_packet_read)
+    drizzle_state_push(result->con, drizzle_state_column_read);
+    drizzle_state_push(result->con, drizzle_state_packet_read);
   }
 
   *ret_ptr= drizzle_state_loop(result->con);
@@ -497,7 +498,8 @@ drizzle_return_t drizzle_column_buffer(drizzle_result_st *result)
                                   result->column_count);
     if (result->column_buffer == NULL)
     {
-      DRIZZLE_ERROR_SET(result->con->drizzle, "drizzle_column_buffer", "malloc")
+      drizzle_set_error(result->con->drizzle, "drizzle_column_buffer",
+                        "malloc");
       return DRIZZLE_RETURN_MEMORY;
     }
   }
@@ -560,11 +562,11 @@ uint16_t drizzle_column_current(drizzle_result_st *result)
 drizzle_return_t drizzle_column_write(drizzle_result_st *result,
                                       drizzle_column_st *column)
 {
-  if (DRIZZLE_STATE_NONE(result->con))
+  if (drizzle_state_none(result->con))
   {
     result->column= column;
 
-    DRIZZLE_STATE_PUSH(result->con, drizzle_state_column_write)
+    drizzle_state_push(result->con, drizzle_state_column_write);
   }
 
   return drizzle_state_loop(result->con);
@@ -699,13 +701,12 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
   drizzle_column_st *column;
   drizzle_column_type_drizzle_t drizzle_type;
 
-  PDEBUG("drizzle_state_column_read", "%5zu %5zu", con->buffer_size,
-         con->packet_size)
+  drizzle_log_debug(con->drizzle, "drizzle_state_column_read");
 
   /* Assume the entire column packet will fit in the buffer. */
   if (con->buffer_size < con->packet_size)
   {
-    DRIZZLE_STATE_PUSH(con, drizzle_state_read)
+    drizzle_state_push(con, drizzle_state_read);
     return DRIZZLE_RETURN_OK;
   }
 
@@ -713,12 +714,12 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
   {
     /* EOF packet marking end of columns. */
     con->result->column= NULL;
-    con->result->warning_count= DRIZZLE_GET_BYTE2(con->buffer_ptr + 1);
-    con->status= DRIZZLE_GET_BYTE2(con->buffer_ptr + 3);
+    con->result->warning_count= drizzle_get_byte2(con->buffer_ptr + 1);
+    con->status= drizzle_get_byte2(con->buffer_ptr + 3);
     con->buffer_ptr+= 5;
     con->buffer_size-= 5;
 
-    DRIZZLE_STATE_POP(con)
+    drizzle_state_pop(con);
   }
   else if (con->result->options & DRIZZLE_RESULT_SKIP_COLUMN)
   {
@@ -726,7 +727,7 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
     con->buffer_size-= con->packet_size;
     con->packet_size= 0;
 
-    DRIZZLE_STATE_PUSH(con, drizzle_state_packet_read)
+    drizzle_state_push(con, drizzle_state_packet_read);
   }
   else
   {
@@ -749,8 +750,8 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
                                 DRIZZLE_MAX_COLUMN_NAME_SIZE);
 
     /* Skip one filler byte. */
-    column->charset= (drizzle_charset_t)DRIZZLE_GET_BYTE2(con->buffer_ptr + 1);
-    column->size= DRIZZLE_GET_BYTE4(con->buffer_ptr + 3);
+    column->charset= (drizzle_charset_t)drizzle_get_byte2(con->buffer_ptr + 1);
+    column->size= drizzle_get_byte4(con->buffer_ptr + 3);
 
     if (con->options & DRIZZLE_CON_MYSQL)
       column->type= con->buffer_ptr[7];
@@ -762,7 +763,7 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
       column->type= _column_type_drizzle_map_to[drizzle_type];
     }
 
-    column->flags= DRIZZLE_GET_BYTE2(con->buffer_ptr + 8);
+    column->flags= drizzle_get_byte2(con->buffer_ptr + 8);
     if (column->type <= DRIZZLE_COLUMN_TYPE_INT24 &&
         column->type != DRIZZLE_COLUMN_TYPE_TIMESTAMP)
     {
@@ -789,7 +790,7 @@ drizzle_return_t drizzle_state_column_read(drizzle_con_st *con)
 
     con->result->column_current++;
 
-    DRIZZLE_STATE_POP(con)
+    drizzle_state_pop(con);
   }
 
   return DRIZZLE_RETURN_OK;
@@ -801,6 +802,8 @@ drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
   uint8_t *ptr;
   drizzle_column_st *column= con->result->column;
 
+  drizzle_log_debug(con->drizzle, "drizzle_state_column_write");
+
   /* Calculate max packet size. */
   con->packet_size= 9 + strlen(column->catalog)
                   + 9 + strlen(column->db)
@@ -820,8 +823,8 @@ drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
   /* Assume the entire column packet will fit in the buffer. */
   if ((con->packet_size + 4) > DRIZZLE_MAX_BUFFER_SIZE)
   {
-    DRIZZLE_ERROR_SET(con->drizzle, "drizzle_state_column_write",
-                      "buffer too small:%zu", con->packet_size + 4)
+    drizzle_set_error(con->drizzle, "drizzle_state_column_write",
+                      "buffer too small:%zu", con->packet_size + 4);
     return DRIZZLE_RETURN_INTERNAL_ERROR;
   }
 
@@ -829,7 +832,7 @@ drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
   if (((size_t)DRIZZLE_MAX_BUFFER_SIZE - (size_t)(start - con->buffer)) <
       con->packet_size)
   {
-    DRIZZLE_STATE_PUSH(con, drizzle_state_write)
+    drizzle_state_push(con, drizzle_state_write);
     return DRIZZLE_RETURN_OK;
   }
 
@@ -850,16 +853,19 @@ drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
   ptr[0]= 12;
   ptr++;
 
-  DRIZZLE_SET_BYTE2(ptr, column->charset)
+  drizzle_set_byte2(ptr, column->charset);
   ptr+= 2;
 
-  DRIZZLE_SET_BYTE4(ptr, column->size)
+  drizzle_set_byte4(ptr, column->size);
   ptr+= 4;
 
-  ptr[0]= column->type;
+  if (con->options & DRIZZLE_CON_MYSQL)
+    ptr[0]= column->type;
+  else
+    ptr[0]= _column_type_drizzle_map_from[column->type];
   ptr++;
 
-  DRIZZLE_SET_BYTE2(ptr, column->flags)
+  drizzle_set_byte2(ptr, column->flags);
   ptr+= 2;
 
   ptr[0]= column->decimals;
@@ -878,11 +884,11 @@ drizzle_return_t drizzle_state_column_write(drizzle_con_st *con)
   con->buffer_size+= (4 + con->packet_size);
 
   /* Store packet size now. */
-  DRIZZLE_SET_BYTE3(start, con->packet_size)
+  drizzle_set_byte3(start, con->packet_size);
 
   con->result->column_current++;
 
-  DRIZZLE_STATE_POP(con)
+  drizzle_state_pop(con);
 
   return DRIZZLE_RETURN_OK;
 }
