@@ -12,7 +12,7 @@
 
 /**
  * @file
- * @brief Visibility control macros
+ * @brief Visibility Control Macros
  */
 
 #ifndef __DRIZZLE_VISIBILITY_H
@@ -30,6 +30,9 @@
 # if defined(HAVE_VISIBILITY)
 #  define DRIZZLE_API __attribute__ ((visibility("default")))
 #  define DRIZZLE_LOCAL  __attribute__ ((visibility("hidden")))
+# elif defined (__SUNPRO_C) && (__SUNPRO_C >= 0x550)
+#  define DRIZZLE_API __global
+#  define DRIZZLE_API __hidden
 # elif defined(_MSC_VER)
 #  define DRIZZLE_API extern __declspec(dllexport) 
 #  define DRIZZLE_LOCAL
