@@ -22,27 +22,27 @@ int main(void)
   drizzle_query_st query_buffer;
   size_t size;
 
-  printf("# sizeof(drizzle_query_st) = %zu\n", sizeof(drizzle_query_st));
+  printf("sizeof(drizzle_query_st) = %zu\n", sizeof(drizzle_query_st));
 
   if ((drizzle= drizzle_create(NULL)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_create");
+    drizzle_test_error("drizzle_create");
 
   if ((query= drizzle_query_create(drizzle, &query_buffer)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_query_create");
+    drizzle_test_error("drizzle_query_create");
   drizzle_query_free(query);
 
   if ((query= drizzle_query_create(drizzle, NULL)) == NULL)
-    DRIZZLE_TEST_ERROR("drizzle_query_create");
+    drizzle_test_error("drizzle_query_create");
 
   if (drizzle_query_options(query) != DRIZZLE_QUERY_ALLOCATED)
-    DRIZZLE_TEST_ERROR("drizzle_query_options");
+    drizzle_test_error("drizzle_query_options");
 
   drizzle_query_set_string(query, "SELECT 1+1", 10);
 
   if (strncmp(drizzle_query_string(query, &size), "SELECT 1+1", 10) ||
       size != 10)
   {
-    DRIZZLE_TEST_ERROR("drizzle_query_string");
+    drizzle_test_error("drizzle_query_string");
   }
 
   drizzle_query_free(query);
